From 6cfe632b603ed259e41b24a100f2a6ac3a45ef1a Mon Sep 17 00:00:00 2001
From: Rong Xu <xur@google.com>
Date: Fri, 17 Mar 2017 20:51:44 +0000
Subject: [PATCH] [PGO] Change the internal options description. nfc.

git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@298120 91177308-0d34-0410-b5e6-96231b3b80d8
---
 lib/Transforms/Instrumentation/PGOInstrumentation.cpp | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/lib/Transforms/Instrumentation/PGOInstrumentation.cpp b/lib/Transforms/Instrumentation/PGOInstrumentation.cpp
index f81c2eda957..7241a2a2e00 100644
--- a/lib/Transforms/Instrumentation/PGOInstrumentation.cpp
+++ b/lib/Transforms/Instrumentation/PGOInstrumentation.cpp
@@ -176,9 +176,11 @@ static cl::opt<bool>
                               "display to only one function, use "
                               "filtering option -view-bfi-func-name."));
 
-// Command line option to enable/disable memop intrinsic calls..
-static cl::opt<bool> PGOInstrMemOP("pgo-instr-memop", cl::init(true),
-                                   cl::Hidden);
+// Command line option to enable/disable memop intrinsic call.size profiling.
+static cl::opt<bool>
+    PGOInstrMemOP("pgo-instr-memop", cl::init(true), cl::Hidden,
+                  cl::desc("Use this option to turn on/off "
+                           "memory instrinsic size profiling."));
 
 // Command line option to turn on CFG dot dump after profile annotation.
 // Defined in Analysis/BlockFrequencyInfo.cpp:  -pgo-view-counts